function [ v ] = vypocek_koef_v( vzd,vzd_m,h_l,h_s,f,h_m )
% vzd - vzdalenost mezi lodi a satelitem (kolmy prumet na vodu)
% vzd_m - zdalenost mostu (uvazovaneho jako knife edge prekazka s nulovou
% sirkou) k satelitu (vzdalenost kolmeho prumetu na vodu)
% h_l - vyska lodi
% h_s - vyska satelitu
% h_m - vyska pocitane hrany mostu
% f - frekvence

vln=((3*10^(8))/(f*10^(6)));
a = atan((vzd_m)/(h_s-h_m));
d_1=sqrt((vzd_m^2)+(h_s-h_m)^2);
d_2=sqrt((vzd-vzd_m)^2+(h_m-h_l)^2);
b=atan(vzd/(h_s-h_l))-a;
h=d_1*sin(b);
v=h*sqrt((2/vln)*((1/d_1)+(1/d_2)));


end

